*******************************************************************************
*REVISION HISTORY:
*
*DATE                   REV. NO.        DESCRIPTION
*
*Setp 11, 1998          1.00            RTC clean up   
*Author: Exequiel Rarama
*******************************************************************************
;
; ----------------------------
; ADAPT-812MX1 Flash Utilities
; ----------------------------

; ---------------------------
; Clock RTC - RTC Routines
; ---------------------------

;clock modes
status1                 equ     %10000011       ;clock control/status register
status2                 equ     %00000011       ;clock control/status register
status3                 equ     %00001011       ;clock control/status register
                                                ; read date and month directly.
rtc_control_reg_address equ     0
millisecond_reg_address equ     1
seconds_reg_address     equ     2
minutes_reg_address     equ     3
hours_reg_address       equ     4
year_date_reg_address   equ     5
week_month_reg_address  equ     6
timer_reg_address       equ     7
alarm_cntrl_reg_address equ     8

rtc_read_address        equ     %10100011       ;address of rtc clock
rtc_write_address       equ     %10100010       ;address of rtc clock

SDA                     EQU     %00100000       ;SERIAL DATA
SCL                     EQU     %01000000       ;SERIAL CLOCK FOR THE DATA
;
;Required Rams variables
;-------------
;RTC Variables
;-------------
;spi_read                ds      1
;spi_write               ds      1

;rtc_reg_address         ds      1
;read_write_flag         ds      1               ;if bit 0 is 0 then write else read
;ack_flag                ds      1               ;acknowledged flag

;time variables
;time_temp
;time_seconds_hundred    ds      1
;time_seconds            ds      1
;time_minutes            ds      1
;time_hours              ds      1
;time_days               ds      1
;time_months             ds      1
;time_years              ds      1

;time_flag               ds      1
;date_flag               ds      1

;
;-----------------------------------------------------------------------------
;
RTC_INIT
        clr     time_flag               ;clear flags for sci parsing
        clr     date_flag
        rts

        clr     time_seconds_hundred
        clr     time_seconds
        clr     time_minutes
        clr     time_hours
;
;Initialize month and date to January 1
        movb    #%00000001,time_months  ;January
        movb    #%00000001,time_days    ;1st

;        movb    #%00010001,time_days   ;eg. shows 11th as the date.

        movb    #%10011000,time_years   ;98 and in this case the year 1998
        bra     TIME_INIT
;
NEW_TIME_INIT
        clr     time_seconds_hundred
        bra     TIME_INIT

NEW_DATE_INIT
        jsr     READ_TIME_HR
        jsr     READ_TIME_MIN
        jsr     READ_TIME_SEC

;
TIME_INIT
        movb    #rtc_write_address,spi_write    ;slave address
        movb    #rtc_control_reg_address,rtc_reg_address ;slave control register

        jsr     WRITE_MOD
;
;status
        ldab    #8
        ldaa    #status1                ;dump status data into rtc
        jsr     clock_bits

        jsr     acknowledge             ;get acknowledge signal from rtc
;
;-------------------------------
;Time are set to 00:00:00:00 in 24h format
;Date are set to Jan 1 and the year to 1. The actual year value (ie 1998) must
; set somewhere else.
;
;hundredths of a second
        ldab    #8                      ;the rtc is auto incremented
        ldaa    time_seconds_hundred    ;address 1
        jsr     clock_bits

        jsr     acknowledge             ;get acknowledge signal from rtc

;seconds
        ldab    #8                      ;the rtc is auto incremented
        ldaa    time_seconds            ;address 2
        jsr     clock_bits

        jsr     acknowledge             ;get acknowledge signal from rtc

;minutes
        ldab    #8                      ;the rtc is auto incremented
        ldaa    time_minutes            ;address 3
        jsr     clock_bits

        jsr     acknowledge             ;get acknowledge signal from rtc

;hours
        ldab    #8                      ;the rtc is auto incremented
        ldaa    time_hours              ;address 4
        jsr     clock_bits

        jsr     acknowledge             ;get acknowledge signal from rtc

        ldaa    time_flag
        bne     time_upx

;year/date
        ldab    #8                      ;the rtc is auto incremented
        ldaa    time_days               ;address 5 - set date to 1st
        jsr     clock_bits              ; and year to 1

        jsr     acknowledge             ;get acknowledge signal from rtc

;weekday/month
        ldab    #8                      ;the rtc is auto incremented
        ldaa    time_months             ;address 6 - set month to 1st
        jsr     clock_bits              ; and weekday 0

        jsr     acknowledge             ;get acknowledge signal from rtc

time_upx
        jsr     stop_condition          ;

        jsr     small_delay
;
;Update to new time and Initialize clock to start counting
;
time_update
        clr     read_write_flag

        movb    #rtc_write_address,spi_write    ;slave address
        movb    #rtc_control_reg_address,rtc_reg_address ;slave control register

        jsr     WRITE_MOD

;status
        ldab    #8
        ldaa    #status2                ;dump status data into rtc
        jsr     clock_bits

        jsr     acknowledge             ;get acknowledge signal from rtc
        jsr     stop_condition          ;

        clr     time_flag
        clr     date_flag

        rts

;-----------------------------------------------------------------------------
GET_TIME
        ldx     #M_CURRENT_TIME         ;Send message
        jsr     SendString
               
        jsr     READ_TIME_HR
        ldaa    time_hours
        jsr     display_time

        ldaa    #':'
        jsr     SendByte

        jsr     READ_TIME_MIN
        ldaa    time_minutes
        jsr     display_time

        ldaa    #':'
        jsr     SendByte

        jsr     READ_TIME_SEC
        ldaa    time_seconds
        jsr     display_time

        jsr     PutNewLine

        ldx     #M_NEW_TIME             ;Send message
        jsr     SendString

;
;-----------------------
;get hour, minunte and second
;

        inc     time_flag               ;set flag to sci parsing
        clr     date_flag

;get hour
        jsr     GetChar

        cmpa    #CR                     ;cr
        beq     time_ex

        cmpa    #$30
        blo     GET_TIME
        cmpa    #$32
        bhi     GET_TIME

        jsr     SB1                     ;Outchar before stripping
        suba    #$30                    ;
        jsr     shift_a
 
        jsr     GetChar
        cmpa    #$30
        blo     GET_TIME
        cmpa    #$33
        bhi     GET_TIME

        jsr     SB1                     ;Outchar before stripping
        anda    #%00001111

        ldab    TEMP1
        aba
        staa    time_hours

        ldaa    #':'
        jsr     SendByte

;get minutes
        jsr     GetChar

        cmpa    #CR                     ;cr
        beq     time_hr_ex

        jsr     get_minutes_second
        staa    time_minutes

        ldaa    #':'
        jsr     SendByte

;get seconds
        jsr     GetChar

        cmpa    #CR                     ;cr
        beq     time_min_ex

        jsr     get_minutes_second
        staa    time_seconds

time_hr_ex
        bra     timex

time_min_ex
        bra     timex

timex
        lbra    NEW_TIME_INIT

time_ex
        clr     time_flag
        rts
;
get_minutes_second
        cmpa    #$30
        lblo    GET_TIME
        cmpa    #$35
        lbhi    GET_TIME

        jsr     SB1                     ;Outchar before stripping
        suba    #$30
        jsr     shift_a
 
        jsr     GetChar
        cmpa    #$30
        lblo    GET_TIME
        cmpa    #$39
        lbhi    GET_TIME

        jsr     SB1                     ;Outchar before stripping
        anda    #%00001111

        ldab    TEMP1
        aba
        rts

shift_a
        anda    #%00001111
        asla                            ;Shift content 4 times
        asla
        asla
        asla
        staa    TEMP1
        rts

display_time
        psha

        asra                            ;Shift contents 4 times to carry
        asra
        asra
        asra

        anda    #%00001111
        adda    #$30

        jsr     SB1                     ;Outchar
 
        pula
        anda    #%00001111
        adda    #$30
        jsr     SB1
        rts

;-----------------------------------------------------------------------------
GET_DATE
        ldx     #M_CURRENT_DATE         ;Send message
        jsr     SendString

        jsr     READ_TIME_YR
        ldaa    time_years
        bsr     display_time

        ldaa    #'/'
        jsr     SendByte

        jsr     READ_TIME_MNTH
        ldaa    time_months
        bsr     display_time

        ldaa    #'/'
        jsr     SendByte

        jsr     READ_TIME_DATE
        ldaa    time_days
        bsr     display_time

        jsr     PutNewLine

        ldx     #M_NEW_DATE         ;Send message
        jsr     SendString

;
;-----------------------
;get year, month and day
;
        clr     time_flag               ;set flag to sci parsing
        inc     date_flag

;get year
        jsr     GetChar

        cmpa    #CR                     ;cr
        lbeq    date_ex

        cmpa    #$30
        blo     GET_DATE
        cmpa    #$39
        bhi     GET_DATE

        jsr     SB1                     ;Outchar before stripping
        suba    #$30                    ;
        jsr     shift_a
 
        jsr     GetChar
        cmpa    #$30
        blo     GET_DATE
        cmpa    #$39
        bhi     GET_DATE

        jsr     SB1                     ;Outchar before stripping
        anda    #%00001111

        ldab    TEMP1
        aba
        staa    time_years

        ldaa    #'/'
        jsr     SendByte

;get months
        jsr     GetChar

        cmpa    #CR                     ;cr
        lbeq    datex

        cmpa    #$30
        blo     GET_DATE
        cmpa    #$31
        lbhi    GET_DATE

        jsr     SB1                     ;Outchar before stripping
        suba    #$30                    ;
        jsr     shift_a
 
        jsr     GetChar
        cmpa    #$30
        lblo    GET_DATE
        cmpa    #$39
        lbhi    GET_DATE

        psha
        anda    #%00001111

        ldab    TEMP1
        aba

        cmpa    #1
        lblo    GET_DATE

        cmpa    #$12
        lbhi    GET_DATE
        staa    time_months

        pula
        jsr     SB1                     ;Outchar before stripping

        ldaa    #'/'
        jsr     SendByte

;get days
        jsr     GetChar

        cmpa    #CR                     ;cr
        lbeq    datex

        cmpa    #$30
        lblo    GET_DATE
        cmpa    #$33
        lbhi    GET_DATE

        jsr     SB1                     ;Outchar before stripping
        suba    #$30                    ;
        jsr     shift_a
 
        jsr     GetChar
        cmpa    #$30
        lblo    GET_DATE
        cmpa    #$39
        lbhi    GET_DATE

        psha
        anda    #%00001111

        ldab    TEMP1
        aba

        cmpa    #1
        lblo    GET_DATE

        cmpa    #$31
        lbhi    GET_DATE
        staa    time_days  

        pula
        jsr     SB1                     ;Outchar before stripping

datex
        lbra    NEW_DATE_INIT

date_ex
        clr     time_flag
        clr     date_flag
        rts

;-----------------------------------------------------------------------------
READ_TIME_SEC
        movb    #seconds_reg_address,rtc_reg_address ;slave control register
        jsr     READ_TIME
        movb    time_temp,time_seconds
        jsr     stop_condition
        rts

READ_TIME_MIN
        movb    #minutes_reg_address,rtc_reg_address ;slave control register
        jsr     READ_TIME
        movb    time_temp,time_minutes
        jsr     stop_condition
        rts

READ_TIME_HR
        movb    #hours_reg_address,rtc_reg_address ;slave control register
        jsr     READ_TIME
        movb    time_temp,time_hours
        jsr     stop_condition
        rts

READ_TIME_DATE
        movb    #rtc_write_address,spi_write    ;slave address
        movb    #rtc_control_reg_address,rtc_reg_address ;slave control register

        jsr     WRITE_MOD

;status
        ldab    #8
        ldaa    #status3                ;dump status data into rtc
        jsr     clock_bits

        jsr     acknowledge             ;get acknowledge signal from rtc
        jsr     stop_condition

        movb    #year_date_reg_address,rtc_reg_address ;slave control register
        bsr     READ_TIME
        movb    time_temp,time_hours
        jsr     stop_condition
        rts

READ_TIME_WEEK
        movb    #week_month_reg_address,rtc_reg_address ;slave control register
        bsr     READ_TIME
        movb    time_temp,time_hours
        jsr     stop_condition
        rts

READ_TIME_MNTH
        movb    #rtc_write_address,spi_write    ;slave address
        movb    #rtc_control_reg_address,rtc_reg_address ;slave control register

        jsr     WRITE_MOD

;status
        ldab    #8
        ldaa    #status3                ;dump status data into rtc
        jsr     clock_bits

        jsr     acknowledge             ;get acknowledge signal from rtc
        jsr     stop_condition

        movb    #week_month_reg_address,rtc_reg_address ;slave control register
        bsr     READ_TIME
        movb    time_temp,time_hours
        jsr     stop_condition
        rts

READ_TIME_YR
        movb    #year_date_reg_address,rtc_reg_address ;slave control register
        bsr     READ_TIME
        movb    time_temp,time_hours
        jsr     stop_condition
        rts

READ_TIME
;
;set slave address and word address
        clr     read_write_flag
        movb    #rtc_write_address,spi_write    ;slave address

        jsr     WRITE_MOD
        jsr     acknowledge             ;get acknowledge signal from rtc

        movb    #1,read_write_flag

        movb    #rtc_read_address,spi_read
        jsr     READ_CMD
        jsr     acknowledge             ;get acknowledge signal from rtc

        clr     time_temp

        ldab    #8
        bsr     SHIFT_BITS
        jsr     acknowledge             ;get acknowledge signal from rtc
        rts

;-----------------------------------------------------------------------------
SHIFT_BITS
        bset    PORTS,SCL               ;Get data from RTC
        jsr     small_delay

        ldaa    PORTS                   ;read bit in
        jsr     small_delay

        bclr    PORTS,SCL
        jsr     small_delay

        anda    #SDA                    ;mask unwanted bits
        clc                             ;clear carry

        asla                            ;Shift content 3 times to carry
        asla
        asla                            ;shift data bit into carry

        rol     time_temp               ;store bit into mem

        decb                            ;decrement counter
        bne     SHIFT_BITS              ;clock bit again if not count down to zero
        rts                             ;function return with new time in time_second buff

;----------------------------------------
WRITE_MOD
        jsr     small_delay             ;do some delay

        bset    DDRS,%01100000          ;make sure bit 6, and 7 are output
        bset    PORTS,%01100000         ;make sure both SDA and SCL are high

        jsr     small_delay             ;do some delay
        jsr     start_condition

        clr     read_write_flag

        jsr     WRITE_CMD               ;go start sequence
        jsr     acknowledge             ;get acknowledge signal from rtc

        ldab    #8
        ldaa    rtc_reg_address         ;word address 0
        jsr     clock_bits
        jsr     acknowledge             ;get acknowledge signal from rtc
        rts

;----------------------------------------
READ_CMD
        jsr     small_delay             ;do some delay

        bset    DDRS,%01100000          ;make sure bit 6, and 7 are output
        bset    PORTS,%01100000         ;make sure both SDA and SCL are high

        jsr     small_delay             ;do some delay

        jsr     start_condition

        ldab    #8
        ldaa    spi_read               ;get rtc address
        bra     clock_bits

;----------------------------------------
WRITE_CMD
        ldab    #8
        ldaa    spi_write               ;get rtc address

clock_bits
        clc                             ;clear carry bit
        asla                            ;move high bit into carry
        bcs     clock_bit_high          ;clock a high bit if carry is set
        bra     clock_bit_low           ;clock a low bit if carry is not set

clock_bit_high
        bset    PORTS,SDA               ;set SDA hi
        jsr     small_delay

        bset    PORTS,SCL               ;strobe SDA
        jsr     small_delay

        bclr    PORTS,SCL
        jsr     small_delay

        decb                            ;decrement counter
        bne     clock_bits              ;clock bit again if not count down to zero
        rts

clock_bit_low
        bclr    PORTS,SDA               ;set SDA lo
        jsr     small_delay

        bset    PORTS,SCL               ;strobe SDA
        jsr     small_delay

        bclr    PORTS,SCL
        jsr     small_delay

        decb                            ;decrement counter
        bne     clock_bits              ;clock bit again if not count down to zero
        rts

start_condition
        bclr    PORTS,SDA               ;set SDA low to start process
        jsr     small_delay

        bclr    PORTS,SCL               ;set SCL low to satisfy start process
        jsr     small_delay
        rts

stop_condition
        bclr    PORTS,SDA               ;set SDA lo
        jsr     small_delay             ;do some delay

        bset    PORTS,SCL               ;set SCL lo
        jsr     small_delay             ;do some delay

        bset    PORTS,SDA               ;set SDA hi
        jsr     small_delay

        rts

acknowledge
        bclr    DDRS,SDA               ;make SDA (bit 7 of PORTC) as input
        jsr     small_delay

        ldab    PORTS

        nop
        nop

        bset    PORTS,SCL
        jsr     small_delay

        bclr    PORTS,SCL
        jsr     small_delay

        andb    #SDA                    ;clear unwanted bits
        clc                             ;clear carry bit before shifting

        aslb                            ;Shift content 3 times to carry
        aslb
        aslb

        bcc     yes_acknowledge         ;check if carry is set

no_acknowledge                          ;carry is not set. No acknowledge
        clr     ack_flag                ;no acknowledge and clear acknowledge flag
        rts

yes_acknowledge                         ;carry is set. There is acknowledge
        inc     ack_flag                ;set acknowledge flag

        ldaa    read_write_flag
        beq     writing
        rts

writing
        bset    DDRS,SDA               ;make SDA (bit 5 of PORTS) as output
        rts

;-----------------------------------------------------------------------------
delay
        pshy
        ldy     #0
        bra     dly

small_delay
        pshy
        ldy     #10    

dly
        dbne    y,dly
        puly
        rts

;------------------------------------------------------------------------------




